import { ILogStyler, TCategoryLevels, LogLevel, ILogger, ILoggerFactory } from "./Types";
export declare function setCategoryLevels(newLevels: TCategoryLevels): void;
/**
 * Get the category level
 *
 * @param name
 * @returns {LogLevel|number}
 */
export declare function categoryLevel(name: string): number;
/**
 * Set global threshold
 *
 * @param level
 */
export declare function setLogThreshold(level: LogLevel): void;
/**
 * Set an override threshold for a logger
 *
 * @param logger
 * @param overrideLevel
 */
export declare function setOverrideLevel(logger: ILogger, overrideLevel: LogLevel): void;
/**
 * Default log factory, uses console
 */
export declare const DefaultLoggerFactory: {
    create(name: string): ILogger;
};
/**
 * Change the internal default logger
 *
 * @export
 * @param newLoggerFactory new logger factory
 */
export declare function setLoggerFactory(newLoggerFactory: ILoggerFactory): void;
/**
 * Set the logger output
 *
 * @param newLoggerOutput
 */
export declare function setLoggerOutput(newLoggerOutput: ILogger): void;
/**
 * Set the styler
 *
 * @param newStyler
 */
export declare function setStyler(newStyler: ILogStyler): void;
/**
 * Get the current styler
 *
 * @returns {ILogStyler}
 */
export declare function getStyler(): ILogStyler;
/**
 * Global prefix for all loggers
 *
 * @param prefix
 */
export declare function setPrefixGlobal(prefix: string): void;
/**
 * Wrap a logger and prepend all log calls
 *
 * @param logger
 * @param prefix
 */
export declare function setPrefix(logger: ILogger, prefix: string): ILogger;
/**
 * Set custom styler enabled
 *
 * @param enabled
 */
export declare function setStylerEnabled(enabled: boolean): void;
/**
 * Create a new logger
 *
 * @param name
 * @returns {ILogger}
 */
export declare function create(name: string): ILogger;
