"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Types_1 = require("./Types");
/**
 * Warn logging message
 *
 * @param msg
 * @param err
 */
function warnLog(msg, err) {
    try {
        console.warn(msg, err);
    }
    catch (err2) { }
}
exports.warnLog = warnLog;
/**
 * Parse log level
 *
 * @param level
 * @returns {any}
 */
function parseLogLevel(level) {
    var logLevel = Types_1.LogLevel.DEBUG;
    try {
        logLevel = Types_1.LogLevel[level.toUpperCase()];
    }
    catch (err) {
        warnLog("Failed to parse log level " + level, err);
        logLevel = Types_1.LogLevel.DEBUG;
    }
    return logLevel;
}
exports.parseLogLevel = parseLogLevel;
/**
 * Format a message value
 *
 * @param value
 * @returns {string}
 */
function formatValue(value) {
    var valueType = typeof value;
    return (['number', 'string', 'boolean'].indexOf(valueType) > -1) ?
        value : JSON.stringify(value, null, 4);
}
exports.formatValue = formatValue;
/**
 * Get a deep property
 *
 * @param obj
 * @param keyPath
 * @returns {any}
 */
function getProp(obj, keyPath) {
    if (!obj)
        return null;
    var keyParts = keyPath.split('.'), key = keyParts.shift(), val = obj[key];
    return (keyParts.length) ? getProp(val, keyParts.join('.')) : val;
}
exports.getProp = getProp;
//# sourceMappingURL=Util.js.map